summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_calcer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kig/objects/object_calcer.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/objects/object_calcer.h')
-rw-r--r--kig/objects/object_calcer.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kig/objects/object_calcer.h b/kig/objects/object_calcer.h
index 92eebc8e..98262e5e 100644
--- a/kig/objects/object_calcer.h
+++ b/kig/objects/object_calcer.h
@@ -90,7 +90,7 @@ public:
*/
void addChild( ObjectCalcer* c );
/**
* a calcer should call this in its destructor, to inform its tqparent
* that it is no longer a child of this calcer. This will release
* the reference taken in addChild..
*/
@@ -106,7 +106,7 @@ public:
virtual ~ObjectCalcer();
/**
* Returns the tqparent ObjectCalcer's of this ObjectCalcer.
*/
virtual std::vector<ObjectCalcer*> parents() const = 0;
/**
@@ -124,7 +124,7 @@ public:
* certain type. This method returns the ObjectImpType that \p o
* should have. \p os is a list of all the parents in order, and
* \p o is part of it. This method will return the ObjectImpType
* that the tqparent should *at least* be. For example, a Translated
* object can translate any sort of object, so it will return
* ObjectImp::stype() here ( the topmost ObjectImpType, that all
* other ObjectImpType's inherit ).
@@ -267,7 +267,7 @@ public:
};
/**
* This is an ObjectCalcer that has a single tqparent, and gets a
* certain property from it in its calc() method.
*
* \see ObjectImp::property
@@ -276,14 +276,14 @@ class ObjectPropertyCalcer
: public ObjectCalcer
{
ObjectImp* mimp;
- ObjectCalcer* mtqparent;
+ ObjectCalcer* mparent;
int mpropid;
public:
/**
* Construct a new ObjectPropertyCalcer, that will get the property
* from tqparent with number propid.
*/
- ObjectPropertyCalcer( ObjectCalcer* tqparent, int propid );
+ ObjectPropertyCalcer( ObjectCalcer* parent, int propid );
~ObjectPropertyCalcer();
const ObjectImp* imp() const;
@@ -291,7 +291,7 @@ public:
void calc( const KigDocument& doc );
int propId() const;
- ObjectCalcer* tqparent() const;
+ ObjectCalcer* parent() const;
const ObjectImpType* impRequirement(
ObjectCalcer* o, const std::vector<ObjectCalcer*>& os ) const;
@@ -90,7 +90,7 @@ public:
void addChild( ObjectCalcer* c );
/**
- * a calcer should call this in its destructor, to inform its tqparent
+ * a calcer should call this in its destructor, to inform its parent
* that it is no longer a child of this calcer. This will release
* the reference taken in addChild..
@@ -106,7 +106,7 @@ public:
virtual ~ObjectCalcer();
/**
- * Returns the tqparent ObjectCalcer's of this ObjectCalcer.
+ * Returns the parent ObjectCalcer's of this ObjectCalcer.
*/
virtual std::vector<ObjectCalcer*> parents() const = 0;
@@ -124,7 +124,7 @@ public:
* should have. \p os is a list of all the parents in order, and
* \p o is part of it. This method will return the ObjectImpType
- * that the tqparent should *at least* be. For example, a Translated
+ * that the parent should *at least* be. For example, a Translated
* object can translate any sort of object, so it will return
* ObjectImp::stype() here ( the topmost ObjectImpType, that all
@@ -267,7 +267,7 @@ public:
};
/**
- * This is an ObjectCalcer that has a single tqparent, and gets a
+ * This is an ObjectCalcer that has a single parent, and gets a
* certain property from it in its calc() method.
*
@@ -276,14 +276,14 @@ class ObjectPropertyCalcer
/**
* Construct a new ObjectPropertyCalcer, that will get the property
- * from tqparent with number propid.
+ * from parent with number propid.
*/